@@ -9,7 +9,7 @@ from keypartx.basemodes.text_edges import text2edges
 import pandas as pd 
 import math, matplotlib
 from itertools import cycle, islice
-
+import coreferee
 nlp = spacy.load('en_core_web_lg')
 nlp.add_pipe('coreferee')
 
@@ -126,7 +126,7 @@ def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_a
         error_noeds.append(error_node)
       nodes.append(node[:-2])
       values.append(degree)
-      nt.add_node(node1,title = node[:-3].replace('nnn'," ") +':'+str(degree),value=degree1,color = color, shape =shape) #value=degree
+      nt.add_node(node1,title = node[:-4].replace('2nnn'," ") +':'+str(degree),value=degree1,color = color, shape =shape) #value=degree
     #nt.add_nodes(nodes, value = values)
 
     weights = []
@@ -146,7 +146,7 @@ def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_a
         all_edges.append(edge)
         
     print('length Gd nodes after error node removed:',len(Gd.nodes))
-    print('all edges after k-core', len(all_edges))
+    print('all edges after k-core: ', len(all_edges))
     
     if plot_graph:
         nt.show_buttons(filter_=['physics']) 
@@ -418,5 +418,5 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
             ntc3.show(str(community_index) + 'example3.html')
             display(HTML(str(community_index) + 'example3.html'))
       if save_folder:
-        ntc3.save_graph('save_folder/{}.html'.format(community_index +1))
+        ntc3.save_graph(save_folder+ '/{}.html'.format(community_index +1))
           
\ No newline at end of file
