@@ -5,8 +5,8 @@ import leidenalg as la
 import igraph as ig 
 import networkx as nx
 
-from matplotlib import colors
-import matplotlib
+from matplotlib import colors as cls
+#import matplotlib
 import numpy as np
 
 
@@ -17,7 +17,7 @@ def dirNN(allNNedges):
     for nne in allNNedges:
         a = nne[0]
         b = nne[1]
-        revNNedges.append((b,a))
+        revNNedges.append([b,a])
     allNNEdges_dir = revNNedges + allNNedges
     return allNNEdges_dir
 
@@ -71,12 +71,12 @@ def wedge_type(all_adjV2N_edges_w=[],allNNEdges_dir_w=[],nn_edges = True, aVn_ed
 
 ## --- Partition --- ## 
 
-def parti(all_edges,com_resolution):
+def parti(all_edges,com_resolution=1):
     Gdc = nx.DiGraph() 
     #all_edges = all_adjV2N_edges_w  + allNNEdges_dir_w
     Gdc.add_weighted_edges_from(all_edges)
     print('length of nodes:',len(Gdc.nodes))
-    print(Gdc.nodes)
+    #print(Gdc.nodes)
 
 
     weights = []
@@ -101,15 +101,15 @@ def parti(all_edges,com_resolution):
 
 
 ## ---Color setting for community network ---##
-def color_list(colorL = False):
+def colorsList(colorL = False):
     if colorL == False:
         colorList = ['darkred','gold','blue','orange','green','purple','lime']
     else:
         colorList = colorL
     colorList_rgba = []
     for color in colorList:
-      colorList_rgba.append(list(colors.to_rgba(color)))
-    print(colorList_rgba)
+      colorList_rgba.append(list(cls.to_rgba(color)))
+    #print(colorList_rgba)
     colorList_rgba1= []
     for i,a in enumerate(np.arange(.01,1,0.05)[::-1]): # do not start with 0 alpha will be no color,  reverse the order 
       for colors in colorList_rgba:
@@ -118,7 +118,7 @@ def color_list(colorL = False):
         else:
           colors[-1]= a
           #print(colors)
-        colors1 = matplotlib.colors.to_hex(colors, keep_alpha=True)
+        colors1 = cls.to_hex(colors, keep_alpha=True)
       
         colorList_rgba1.append(colors1)
     return colorList_rgba1
